==> jc-1.4.0.tar.gz: jas/MultiarrayInsn.h <==
// public class jas.MultiarrayInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 3253375f30408e00 jas_MultiarrayInsn
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_MultiarrayInsn_H_
#define _JC_jas_MultiarrayInsn_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_MultiarrayInsn$sub_refs	_jc_jas_MultiarrayInsn$sub_refs;
typedef struct _jc_jas_MultiarrayInsn$sub_nonrefs	_jc_jas_MultiarrayInsn$sub_nonrefs;
typedef struct _jc_jas_MultiarrayInsn$refs	_jc_jas_MultiarrayInsn$refs;
typedef struct _jc_jas_MultiarrayInsn$nonrefs	_jc_jas_MultiarrayInsn$nonrefs;
typedef struct _jc_jas_MultiarrayInsn$object	_jc_jas_MultiarrayInsn$object;

typedef const struct _jc_jas_MultiarrayInsn$vmethods	_jc_jas_MultiarrayInsn$vmethods;
typedef const struct _jc_jas_MultiarrayInsn$vtable	_jc_jas_MultiarrayInsn$vtable;
typedef const struct _jc_jas_MultiarrayInsn$vtype	_jc_jas_MultiarrayInsn$vtype;

// Constructors
extern void _jc_jas_MultiarrayInsn$method$_init$ac87c5b24fe5e7ef(_jc_env *, struct _jc_jas_MultiarrayInsn$object *, struct _jc_jas_CP$object *, jint);

// Virtual methods structure
struct _jc_jas_MultiarrayInsn$vmethods {
};

// Vtable
struct _jc_jas_MultiarrayInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_MultiarrayInsn$vmethods	jas_MultiarrayInsn;
};

// Vtype
struct _jc_jas_MultiarrayInsn$vtype {
	_jc_type			type;
	_jc_jas_MultiarrayInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_MultiarrayInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_MultiarrayInsn$refs {
    _jc_jas_MultiarrayInsn$sub_refs	jas_MultiarrayInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_MultiarrayInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_MultiarrayInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_MultiarrayInsn$sub_nonrefs	jas_MultiarrayInsn;
};

// Object instance structure
struct _jc_jas_MultiarrayInsn$object {
	_jc_jas_MultiarrayInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_MultiarrayInsn$vtype	*vtype;
	_jc_jas_MultiarrayInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_MultiarrayInsn$vtype _jc_jas_MultiarrayInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_MultiarrayInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_MultiarrayInsn$class_object;

#endif	/* _JC_jas_MultiarrayInsn_H_ */

==> jc-1.4.6.tar.gz: jas/MultiarrayInsn.h <==
// public class jas.MultiarrayInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 3253375f30408e00 jas_MultiarrayInsn
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_MultiarrayInsn_H_
#define _JC_jas_MultiarrayInsn_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_MultiarrayInsn$sub_refs	_jc_jas_MultiarrayInsn$sub_refs;
typedef struct _jc_jas_MultiarrayInsn$sub_nonrefs	_jc_jas_MultiarrayInsn$sub_nonrefs;
typedef struct _jc_jas_MultiarrayInsn$refs	_jc_jas_MultiarrayInsn$refs;
typedef struct _jc_jas_MultiarrayInsn$nonrefs	_jc_jas_MultiarrayInsn$nonrefs;
typedef struct _jc_jas_MultiarrayInsn$object	_jc_jas_MultiarrayInsn$object;

typedef const struct _jc_jas_MultiarrayInsn$vmethods	_jc_jas_MultiarrayInsn$vmethods;
typedef const struct _jc_jas_MultiarrayInsn$vtable	_jc_jas_MultiarrayInsn$vtable;
typedef const struct _jc_jas_MultiarrayInsn$vtype	_jc_jas_MultiarrayInsn$vtype;

// Constructors
extern void _jc_jas_MultiarrayInsn$method$_init$ac87c5b24fe5e7ef(_jc_env *, struct _jc_jas_MultiarrayInsn$object *, struct _jc_jas_CP$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_MultiarrayInsn$vmethods {
};

// Vtable
struct _jc_jas_MultiarrayInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_MultiarrayInsn$vmethods	jas_MultiarrayInsn;
};

// Vtype
struct _jc_jas_MultiarrayInsn$vtype {
	_jc_type			type;
	_jc_jas_MultiarrayInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_MultiarrayInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_MultiarrayInsn$refs {
    _jc_jas_MultiarrayInsn$sub_refs	jas_MultiarrayInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_MultiarrayInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_MultiarrayInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_MultiarrayInsn$sub_nonrefs	jas_MultiarrayInsn;
};

// Object instance structure
struct _jc_jas_MultiarrayInsn$object {
	_jc_jas_MultiarrayInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_MultiarrayInsn$vtype	*vtype;
	_jc_jas_MultiarrayInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_MultiarrayInsn$vtype _jc_jas_MultiarrayInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_MultiarrayInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_MultiarrayInsn$class_object;

#endif	/* _JC_jas_MultiarrayInsn_H_ */
